Documentation
¶
Overview ¶
Package etc represents Linux '/etc'.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var MtabSchema = schema.RawData{ IsYAML: false, Columns: []schema.Column{ {Name: "file-system", Godoc: "file system", Kind: reflect.String}, {Name: "mounted-on", Godoc: "'mounted on'", Kind: reflect.String}, {Name: "file-system-type", Godoc: "file system type", Kind: reflect.String}, {Name: "options", Godoc: "file system type", Kind: reflect.String}, {Name: "dump", Godoc: "number indicating whether and how often the file system should be backed up by the dump program; a zero indicates the file system will never be automatically backed up", Kind: reflect.Int}, {Name: "pass", Godoc: "number indicating the order in which the fsck program will check the devices for errors at boot time; this is 1 for the root file system and either 2 (meaning check after root) or 0 (do not check) for all other devices", Kind: reflect.Int}, }, ColumnsToParse: map[string]schema.RawDataType{}, }
MtabSchema represents '/etc/mtab'. Reference https://en.wikipedia.org/wiki/Fstab and https://en.wikipedia.org/wiki/Mtab).
Functions ¶
This section is empty.
Types ¶
type Mtab ¶
type Mtab struct {
// FileSystem is file system.
FileSystem string `column:"file_system"`
// MountedOn is 'mounted on'.
MountedOn string `column:"mounted_on"`
// FileSystemType is file system type.
FileSystemType string `column:"file_system_type"`
// Options is file system type.
Options string `column:"options"`
// Dump is number indicating whether and how often the file system should be backed up by the dump program; a zero indicates the file system will never be automatically backed up.
Dump int `column:"dump"`
// Pass is number indicating the order in which the fsck program will check the devices for errors at boot time; this is 1 for the root file system and either 2 (meaning check after root) or 0 (do not check) for all other devices.
Pass int `column:"pass"`
}
Mtab is '/etc/mtab' in Linux.
Click to show internal directories.
Click to hide internal directories.